@@ -15,6 +15,7 @@
 #include <QStyledItemDelegate>
 #include <QSortFilterProxyModel>
 #include <QStandardItemModel>
+#include <QTextStream>
 #include <qcolor.h>
 #include <qmenu.h>
 #include <qtimer.h>
@@ -34,9 +35,9 @@
 #define SEPARATE_READ_JOBS_COL 0
 #define VERBOSE_PROGRESS_INFO 0
 
-using namespace KDirStat;
+namespace KDirStat {
 
-class KDirStat::KDirModel: public QStandardItemModel {
+class KDirModel: public QStandardItemModel {
   KDirTreeView & view_;
   QStringList headers_;
 
@@ -95,7 +96,16 @@ public:
 
   void removeFile(KFileInfo* file) {
     QModelIndex tr = fileToIndex(file, false);
-    removeRow(tr.row(), parent(tr));
+    QModelIndex parentIdx = parent(tr);
+    removeRow(tr.row(), parentIdx);
+    // Refresh parents
+    QStandardItem * si = itemFromIndex(parentIdx);
+    while(si != nullptr) {
+      QModelIndex begin = si->index();
+      QModelIndex end = begin.siblingAtColumn(columnCount() - 1);
+      emit dataChanged(begin, end);
+      si = si->parent();
+    }
   }
 
   void updateData(QModelIndex r = QModelIndex()) {
@@ -167,7 +177,7 @@ public:
     } else if(column == view_.percentBarCol() && _orig->isDir() && _orig->isExcluded()) {
       return i18n("[excluded]");
     } else if(column == view_.totalSubDirsCol() && _orig->isDir()) {
-      return " " + formatCount(_orig->totalSubDirs());
+      return QVariant(" " + formatCount(_orig->totalSubDirs()));
     } else if(column == view_.readJobsCol() && multi) {
 #if SEPARATE_READ_JOBS_COL
       return " " + formatCount(_orig->pendingReadJobs(), true);
@@ -177,11 +187,11 @@ public:
         formatCount(_orig->pendingReadJobs(), true)) : "";
 #endif
     } else if(column == view_.totalSizeCol() && multi) {
-      return prefix + formatSize(_orig->totalSize());
+      return QVariant(prefix + formatSize(_orig->totalSize()));
     } else if(column == view_.totalItemsCol() && multi) {
-      return prefix + formatSizeLong(_orig->totalItems());
+      return QVariant(prefix + formatSizeLong(_orig->totalItems()));
     } else if(column == view_.totalFilesCol() && multi) {
-      return prefix + formatSizeLong(_orig->totalFiles());
+      return QVariant(prefix + formatSizeLong(_orig->totalFiles()));
     } else if(column == view_.nameCol())
       return _orig->isDotEntry() ? i18n("<Files>") :  _orig->name();
     else if(column == view_.latestMtimeCol()) {
@@ -284,6 +294,8 @@ protected:
     if (column == _view->totalSizeCol() || column == _view->percentNumCol() ||
       column == _view->percentBarCol())
       return _orig->totalSize() > otherOrig->totalSize();
+    else if (column == _view->nameCol())
+      return _orig->name() > otherOrig->name();
     else if (column == _view->ownSizeCol())
       return _orig->size() > otherOrig->size();
     else if (column == _view->totalItemsCol())
@@ -329,7 +341,8 @@ public:
       o.rect = option.rect;
       o.minimum = 0;
       o.maximum = 100;
-      o.progress = 100 * item->totalSize() / item->parent()->totalSize();
+      KFileSize ps = item->parent()->totalSize();
+      o.progress = ps == 0 ? 100 : 100 * item->totalSize() / ps;
       o.palette.setColor(QPalette::Highlight,
                          view->fillColor(item->treeLevel() - 1));
       if (view->selection() != item)
@@ -511,7 +524,7 @@ void KDirTreeView::idleDisplay() {
     // semantics like the percentage bar column (that had doubled as the
     // read job column while reading) now has.
 
-    sortByColumn(_percentNumCol);
+    sortByColumn(_percentNumCol, Qt::AscendingOrder);
   }
 #endif
   _readJobsCol = -1;
@@ -578,7 +591,7 @@ void KDirTreeView::prepareReading() {
 
   // Change display to busy state
 
-  sortByColumn(_totalSizeCol);
+  sortByColumn(_totalSizeCol, Qt::AscendingOrder);
   busyDisplay();
   emit startingReading();
 
@@ -792,7 +805,7 @@ void KDirTreeView::updateSelection(KDirTree * tree) {
 
 const QColor &KDirTreeView::fillColor(int level) const {
   if (level < 0) {
-    qWarning() << Q_FUNC_INFO << "Invalid argument: " << level << endl;
+    qWarning() << Q_FUNC_INFO << "Invalid argument: " << level << Qt::endl;
     level = 0;
   }
 
@@ -802,7 +815,7 @@ const QColor &KDirTreeView::fillColor(int level) const {
 const QColor &KDirTreeView::rawFillColor(int level) const {
   if (level < 0 || level > KDirTreeViewMaxFillColor) {
     level = 0;
-    qWarning() << Q_FUNC_INFO << "Invalid argument: " << level << endl;
+    qWarning() << Q_FUNC_INFO << "Invalid argument: " << level << Qt::endl;
   }
 
   return _fillColor[level % KDirTreeViewMaxFillColor];
@@ -815,11 +828,11 @@ void KDirTreeView::setFillColor(int level, const QColor &color) {
 
 void KDirTreeView::setUsedFillColors(int usedFillColors) {
   if (usedFillColors < 1) {
-    qWarning() << Q_FUNC_INFO << "Invalid argument: " << usedFillColors << endl;
+    qWarning() << Q_FUNC_INFO << "Invalid argument: " << usedFillColors << Qt::endl;
     usedFillColors = 1;
   } else if (usedFillColors >= KDirTreeViewMaxFillColor) {
     qWarning() << Q_FUNC_INFO << "Invalid argument: " << usedFillColors
-               << " (max: " << KDirTreeViewMaxFillColor - 1 << ")" << endl;
+               << " (max: " << KDirTreeViewMaxFillColor - 1 << ")" << Qt::endl;
     usedFillColors = KDirTreeViewMaxFillColor - 1;
   }
 
@@ -852,7 +865,7 @@ void KDirTreeView::setDefaultFillColors() {
 
 void KDirTreeView::setTreeBackground(const QColor &color) {
   _treeBackground = color;
-  _percentageBarBackground = _treeBackground.dark(115);
+  _percentageBarBackground = _treeBackground.darker(115);
 
   QGuiApplication *app =
       dynamic_cast<QGuiApplication *>(QCoreApplication::instance());
@@ -880,7 +893,7 @@ void KDirTreeView::popupContextMenu(const QPoint &localPos) {
   KFileInfo *orig = model()->indexToFile(proxyModel()->mapToSource(idx));
 
   if (!orig) {
-    qCritical() << "NULL item->orig()" << endl;
+    qCritical() << "NULL item->orig()" << Qt::endl;
     return;
   }
 
@@ -972,6 +985,11 @@ void KDirTreeView::popupContextInfo(const QPoint &pos, const QString &info) {
   _contextInfo->popup(pos);
 }
 
+/** Convert an int to a QString using the "%02d" printf format */
+static QString intToStr(int value) {
+  return QStringLiteral("%1").arg(value, 2, 10, QLatin1Char('0'));
+}
+
 void KDirTreeView::readConfig() {
   KConfigGroup config = KSharedConfig::openConfig()->group("Tree Colors");
   _usedFillColors = config.readEntry("usedFillColors", -1);
@@ -989,9 +1007,7 @@ void KDirTreeView::readConfig() {
     QColor defaultColor(Qt::blue);
 
     for (int i = 0; i < KDirTreeViewMaxFillColor; i++) {
-      QString name;
-      name.sprintf("fillColor_%02d", i);
-      _fillColor[i] = config.readEntry(name, defaultColor);
+      _fillColor[i] = config.readEntry("fillColor_" + intToStr(i), defaultColor);
     }
   }
 
@@ -1005,9 +1021,7 @@ void KDirTreeView::saveConfig() const {
   config.writeEntry("usedFillColors", _usedFillColors);
 
   for (int i = 0; i < KDirTreeViewMaxFillColor; i++) {
-    QString name;
-    name.sprintf("fillColor_%02d", i);
-    config.writeEntry(name, _fillColor[i]);
+    config.writeEntry("fillColor_" + intToStr(i), _fillColor[i]);
   }
 }
 
@@ -1032,7 +1046,7 @@ QString KDirTreeView::asciiDump(QModelIndex & idx) const {
 void KDirTreeView::sendMailToOwner() {
   QModelIndexList indices = selectedIndexes();
   if (indices.empty()) {
-    qCritical() << Q_FUNC_INFO << "Nothing selected!" << endl;
+    qCritical() << Q_FUNC_INFO << "Nothing selected!" << Qt::endl;
     return;
   }
   QModelIndex idx = indices.at(0);
@@ -1052,8 +1066,8 @@ void KDirTreeView::sendMailToOwner() {
   QUrl mail;
   mail.setScheme("mailto");
   mail.setPath(owner);
-  mail.setQuery("?subject=" + QUrl::toPercentEncoding(subject) +
-                "&body=" + QUrl::toPercentEncoding(body));
+  mail.setQuery(QString("?subject=" + QUrl::toPercentEncoding(subject) +
+                "&body=" + QUrl::toPercentEncoding(body)));
 
   // TODO: Check for maximum command line length.
   //
@@ -1070,11 +1084,11 @@ void KDirTreeView::resizeIndexToContents(const QModelIndex &index) {
 }
 
 
-QString KDirStat::formatSizeLong(KFileSize size) {
+QString formatSizeLong(KFileSize size) {
   return QLocale().toString(size);
 }
 
-QString KDirStat::hexKey(KFileSize size) {
+QString hexKey(KFileSize size) {
   /**
    * This is optimized for performance, not for aesthetics.
    * And every now and then the old C hacker breaks through in most of us...
@@ -1096,8 +1110,7 @@ QString KDirStat::hexKey(KFileSize size) {
   return QString(key);
 }
 
-QString KDirStat::formatTime(long millisec, bool showMilliSeconds) {
-  QString formattedTime;
+QString formatTime(long millisec, bool showMilliSeconds) {
   int hours;
   int min;
   int sec;
@@ -1110,17 +1123,14 @@ QString KDirStat::formatTime(long millisec, bool showMilliSeconds) {
 
   sec = millisec / 1000L;
   millisec %= 1000L;
-
+  QString formattedTime = intToStr(hours) + ":" + intToStr(min) + ":" + intToStr(sec);
   if (showMilliSeconds) {
-    formattedTime.sprintf("%02d:%02d:%02d.%03ld", hours, min, sec, millisec);
-  } else {
-    formattedTime.sprintf("%02d:%02d:%02d", hours, min, sec);
+    formattedTime += QStringLiteral(".%1").arg(millisec, 3, 10, QLatin1Char('0'));
   }
-
   return formattedTime;
 }
 
-QString KDirStat::formatCount(int count, bool suppressZero) {
+QString formatCount(int count, bool suppressZero) {
   if (suppressZero && count == 0)
     return "";
 
@@ -1130,15 +1140,11 @@ QString KDirStat::formatCount(int count, bool suppressZero) {
   return countString;
 }
 
-QString KDirStat::formatPercent(float percent) {
-  QString percentString;
-
-  percentString.sprintf("%.1f%%", percent);
-
-  return percentString;
+QString formatPercent(float percent) {
+  return QString::number(percent, 'f', 1) + "%";
 }
 
-QString KDirStat::formatTimeDate(time_t rawTime) {
+QString formatTimeDate(time_t rawTime) {
   QString timeDateString;
   struct tm *t = localtime(&rawTime);
 
@@ -1178,32 +1184,33 @@ QString KDirStat::formatTimeDate(time_t rawTime) {
    * Stefan Hundhammer <sh@suse.de>	2001-05-28
    * (in quite some fit of frustration)
    */
-  timeDateString.sprintf("%4d-%02d-%02d  %02d:%02d:%02d", t->tm_year + 1900,
-                         t->tm_mon +
-                             1, // another brain-dead common pitfall - 0..11
-                         t->tm_mday, t->tm_hour, t->tm_min, t->tm_sec);
-
+  QTextStream s(&timeDateString);
+  s << qSetFieldWidth(4) << (t->tm_year + 1900) << qSetFieldWidth(0) << "-"
+    << intToStr(t->tm_mon + 1) << "-" << intToStr(t->tm_mday) << "  "
+    << intToStr(t->tm_hour) << ":" << intToStr(t->tm_min) << ":"
+    << intToStr(t->tm_sec);
   return timeDateString;
 }
 
-QString KDirStat::localeTimeDate(time_t rawTime) {
+QString localeTimeDate(time_t rawTime) {
   QDateTime timeDate;
   timeDate.setTime_t(rawTime);
   return timeDate.toString(Qt::DefaultLocaleShortDate);
 }
 
-QColor KDirStat::contrastingColor(const QColor &desiredColor,
+QColor contrastingColor(const QColor &desiredColor,
                                   const QColor &contrastColor) {
   if (desiredColor != contrastColor) {
     return desiredColor;
   }
 
-  if (contrastColor != contrastColor.light()) {
+  if (contrastColor != contrastColor.lighter()) {
     // try a little lighter
-    return contrastColor.light();
+    return contrastColor.lighter();
   } else {
     // try a little darker
-    return contrastColor.dark();
+    return contrastColor.darker();
   }
 }
 
+} //namespace
